RecordingInput

Enum RecordingInput 

pub enum RecordingInput {
    Mono(u32),
    MonoReaRoute(u32),
    Stereo(u32),
    StereoReaRoute(u32),
    Midi {
        device_id: Option<MidiInputDeviceId>,
        channel: Option<Channel>,
    },
}
Recording input of a track.

Variants



Mono(u32)

Index refers to a single mono channel.



MonoReaRoute(u32)

Index refers to a single ReaRoute mono channel.



Stereo(u32)

Index refers to the first of two channels in a stereo channel pair.



StereoReaRoute(u32)

Index refers to the first of two channels in a ReaRoute stereo channel pair.



Midi

Fields

channel: Option<Channel>

Implementations

Source

impl RecordingInput

pub fn try_from_raw( rec_input_index: i32, ) -> Result<RecordingInput, TryFromRawError<i32>>

Converts an integer as returned by the low-level API to a recording input.

Errors

Fails if the given integer is not a valid recording input index.

pub fn to_raw(&self) -> i32

Converts this value to an integer as expected by the low-level API.