pub enum WindowContext {
NoWindow,
Win(Hwnd),
}Expand description
Allows one to pass a window handle to the action function.
The concrete meaning of this depends on the action. For many actions this is not relevant at all.
Variants
Implementations